Announcements | Scientific Computing

Skip Navigation
This page features MathJax technology to render mathematical formulae. If you are using a screen reader, please visit MathPlayer to download the plugin for your browser. Please note that this is an Internet Explorer-only plugin at this time.

# Scientific Computing

## Top Navigation Bar

Jobs Team Contact Us About Us
Courses Profile Course Records Settings Course Preferences Logout

# Scientific Computing
by J. Nathan Kutz

## Announcements

### Scientific Computing course ending information

On December 16th, Scientific Computing will be closing for this session.
All quizzes and homework assignments need to be completed and finalized by December 15th at 11:59pm PST. Currently enrolled students can continue to access the course via a “Course Archive” button on the Coursera landing page for the course.
If you or others are interested in taking this Scientific Computing class again we plan to offer the course again on Coursera beginning January 7th, 2013.
Dr. Nathan Kutz will be offering a new course beginning January 7th entitled Computational Methods for Data Analysis which can be found on Coursera.
Thanks you for your participation in this course.
The University of Washington
Mon 3 Dec 2012 2:00 PM PST -0800

### Week 8 cheb.m matlab file to be accessed.

Hello and welcome to week 8.
Please find the needed file that you will need for Week 8 at the following link: cheb.m MATLAB Document for week 8
Tue 13 Nov 2012 1:03 PM PST -0800

### Quiz Attempts

Weekly Lecture Quiz attempts

- You now have TWO attempts ONLY to complete the quizzes assigned. (This is retroactive.)
- Quizes are timed.
- Once opened, You have 3 hours to complete them before they close; Give yourself enough time to complete the quiz.
- Quiz names have been updated to be more reflective of their association with each lecture.

Before attempting, be sure that you have viewed the lectures and read the notes so that you are fully prepared to answer the questions.
Tue 2 Oct 2012 8:54 AM PDT -0700

### Video Lecture Downloads

Thank you for enrolling in this free course. The University of Washington is committed to working with some of the world's leading instructors to provide high quality, free education, globally.

We have removed the ability to download course video from Coursera for a number of reasons:

1. Our video contains functionality which only works within the Coursera environment. Downloading it to another platform, such as YouTube, prevents this from working as designed.
2. Our ability to bring you a free course means that we must protect its content so that it is viewed as intended, as a component of an instructionally coherent educational program in Coursera.

We apologize if this is an inconvenience for some students who would prefer more flexibility for viewing this free content. Along with the free course offering, we also provide the added opportunity for Coursera students to enroll in one of our leading Certificate programs.

We hope that you understand our need to maintain a quality standard and continue to enjoy the course.

The University of Washington

Fri 28 Sep 2012 9:37 AM PDT -0700

### Keep Learning about Scientific Computing

Thank you for enrolling in Scientific Computing. Given your interest in this area of study, you may want to learn more about the Certificate in Scientific Computing offered online through the University of Washington.
By enrolling in the UW certificate program, you gain access to the enhanced version of each of the courses, which includes interaction with an instructor, additional assignments, readings, and multimedia material. Plus, you earn a valuable UW credential.
The deadline to apply for this program is 5 p.m. Pacific Daylight Time on October 8, 2012. Details on how to apply are available online. Feel free to contact a UW enrollment adviser by e-mail at info@pce.uw.edu or by phone at 888-469-6499, if you have additional questions.
If you’re unable to commit to the full program at this time but would like to consider enrolling in the future, sign up for e-mail notifications on the UW Certificate in Scientific Computing website.
Once again, thank you for joining us in this course!
Mon 24 Sep 2012 12:00 PM PDT -0700

### Welcome to the Scientific Computing course!

Thank you for joining Scientific Computing! Please take a few moments to read through the course welcome page and watch the welcome video. There is a lot of useful information there about the course.
For now, you should plan to allocate between 10 and 15 hours per week on the Scientific Computing course. There will be roughly 2 hours of lectures per week, as well as weekly homework assignments. The homework assignments will consist of computation exercises and assignments using information contained in both the lecture as well as the course lecture notes packet. You will need to download the course lecture notes packet to be able to complete some of the quiz questions as well as a reference for the course. This may be downloaded in the course resources or at the following link. Course Lecture Notes Packet
A text book is not necessary as the course is self-contained and the course notes are provided. To be successful in the course, a strong background in linear algebra is required. Familiarity with methods of ordinary differential equations and basic programming structure is also required. With this background, you should be able to develop the formulas necessary for the homework in the course.
Given the computational nature of the course, access to MATLAB (www.mathworks.com) or Octave (www.gnu.org/software/octave) is essential. MATLAB provides student editions for $99 that can be downloaded via the web. Octave is a free (or by donation) alternative to MATLAB that can also be downloaded and installed via the web. Either software should suffice for all the needs of the course, but MATLAB is the strongly recommended alternative.
My goal is that by the end of the course you will be able to investigate the flexibility and power of project-oriented computational analysis.. It has been a lot of work and a lot of fun getting this course ready for you. I sincerely hope you enjoy it!
Nathan Kutz
Mon 24 Sep 2012 12:00 AM PDT -0700